.button-with-padding {
    padding: 10px 15px !important;
}
.actions-buttons {
    text-align: center;
    padding: 1em 0 0 0
}
.centered-image {
    display: block;
    margin-left: auto;
    margin-right: auto;
}
.centered-text {
    text-align: center;
}

/*hide arrows for token field*/
#id_token-otp_token::-webkit-outer-spin-button,
#id_token-otp_token::-webkit-inner-spin-button {
  -webkit-appearance: none;
  margin: 0;
}

#id_token-otp_token {
    -moz-appearance:textfield; /* Firefox */
}
