.base{display:-ms-flexbox;display:flex;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;align-items:center;height:100vh;background:#f8f8f8;font-family:Roboto,Lucida Grande,DejaVu Sans,Bitstream Vera Sans,Verdana,Arial,sans-serif}.base,p{font-size:13px}.container{background:#fff;border:1px solid #eaeaea;border-radius:4px;overflow:hidden;width:28em;min-width:300px;margin:100px auto}.header{color:#fff;background:#417690;position:sticky;top:0;z-index:1;height:auto;padding:10px 16px;font-size:22px}.content{padding:20px}.content h1{margin-top:0}.content h2,.content h3{margin-bottom:5px}p{margin:0}form{padding:20px 0 0}.btn{background:#79aec8;padding:10px 15px;border:none;border-radius:4px;color:#fff;cursor:pointer;margin:2px 0;vertical-align:middle;font-family:Roboto,Lucida Grande,Verdana,Arial,sans-serif;font-weight:400;font-size:13px;text-decoration:none;display:inline-block}.btn:hover{background:#417690}.btn.btn-disabled{cursor:not-allowed;background-color:#d8d8d8}.btn.btn-default{background-color:transparent;border:1px solid #79aec8;color:#79aec8}.btn.btn-default:hover{background-color:#417690;border-color:#417690;color:#fff}.form-field{margin-bottom:20px}.form-field input{display:inline-block;border:1px solid #ccc;border-radius:4px;padding:5px 6px;margin-top:0;clear:both;padding:8px;width:100%;box-sizing:border-box}form>.errorlist{margin-top:0}.errorlist{list-style:none;background-color:#fff;color:#ba2121;padding:10px;border:1px solid #ba2121;border-radius:4px}.d-none{display:none}.button-row{display:-ms-flexbox;display:flex;-ms-flex-pack:justify;justify-content:space-between}.m-top{margin-top:10px}.m-bottom{margin-bottom:20px}label{margin-bottom:5px;display:inline-block;font-size:12px}
.notification--error{color: red;}
