{% extends "two_factor/admin/_base_focus.html" %}
{% load i18n %}

{% block content %}
  <h1>{% block title %}{% trans "Permission Denied" %}{% endblock %}</h1>

  <p>{% blocktrans trimmed %}The page you requested, enforces users to verify using
    two-factor authentication for security reasons. You need to enable these
    security features in order to access this page.{% endblocktrans %}</p>

  <p>{% blocktrans trimmed %}Two-factor authentication is not enabled for your
    account. Enable two-factor authentication for enhanced account
    security.{% endblocktrans %}</p>
  <p>
    <a href="javascript:history.go(-1)"
       class="float-right btn btn-link">{% trans "Go back" %}</a>
    <a href="{% url 'admin:two_factor:setup' %}" class="btn btn-primary">
    {% trans "Enable Two-Factor Authentication" %}</a>
  </p>
{% endblock %}
