{% extends "admin/base_site.html" %}
{% load static i18n %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'two_factor/css/style.css' %}">
    <link rel="stylesheet" type="text/css" href="{% static "admin/css/login.css" %}">
{% endblock %}

{% block bodyclass %}{{ block.super }} login{% endblock %}
{% block breadcrumbs %}{% endblock %}